ams.main
========

.. automodule:: ams.main

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      config_logger
      demo
      doc
      edit_conf
      find_log_path
      load
      misc
      print_license
      remove_output
      run
      run_case
      save_conf
      selftest
      set_logger_level
      versioninfo
   
   

   
   
   

   
   
   



